@@ -16,7 +16,7 @@ except:
     sys.exit(1)
 
 print 'maascan version: ', mas.masscan_version
-mas.scan('172.0.8.78/24', ports='22,80,8080')
+mas.scan('120.24.234.46', ports='22,80,8080')
 print 'maascan command line: ', mas.command_line
 #print 'maascan scaninfo: ', mas.scaninfo
 #print 'maascan scanstats: ', mas.scanstats
